@@ -111,6 +111,23 @@ class AxesDatabaseHandlerTestCase(AxesHandlerBaseTestCase):
     def test_handler_without_reset(self):
         self.check_handler()
 
+    @override_settings(AXES_FAILURE_LIMIT=lambda *args: 3)
+    def test_handler_callable_failure_limit(self):
+        self.check_handler()
+
+    @override_settings(AXES_FAILURE_LIMIT='axes.tests.base.custom_failure_limit')
+    def test_handler_str_failure_limit(self):
+        self.check_handler()
+
+    @override_settings(AXES_FAILURE_LIMIT=None)
+    def test_handler_invalid_failure_limit(self):
+        with self.assertRaises(TypeError):
+            self.check_handler()
+
+    @override_settings(AXES_LOCK_OUT_AT_FAILURE=False)
+    def test_handler_without_lockout(self):
+        self.check_handler()
+
     @patch('axes.handlers.database.log')
     def test_empty_request(self, log):
         self.check_empty_request(log, 'AxesDatabaseHandler')
@@ -138,6 +155,10 @@ class AxesCacheHandlerTestCase(AxesHandlerBaseTestCase):
     def test_handler_without_reset(self):
         self.check_handler()
 
+    @override_settings(AXES_LOCK_OUT_AT_FAILURE=False)
+    def test_handler_without_lockout(self):
+        self.check_handler()
+
     @patch('axes.handlers.cache.log')
     def test_empty_request(self, log):
         self.check_empty_request(log, 'AxesCacheHandler')
