@@ -2,10 +2,11 @@ from datetime import timedelta
 from hashlib import md5
 from unittest.mock import patch
 
-from django.http import JsonResponse, HttpResponseRedirect, HttpResponse
+from django.http import JsonResponse, HttpResponseRedirect, HttpResponse, HttpRequest
 from django.test import override_settings, RequestFactory
 
 from axes import get_version
+from axes.apps import AppConfig
 from axes.models import AccessAttempt
 from axes.tests.base import AxesTestCase
 from axes.helpers import (
@@ -21,8 +22,8 @@ from axes.helpers import (
     is_ip_address_in_blacklist,
     is_ip_address_in_whitelist,
     is_client_method_whitelisted,
+    toggleable,
 )
-from axes.request import AxesHttpRequest
 
 
 class VersionTestCase(AxesTestCase):
@@ -31,6 +32,21 @@ class VersionTestCase(AxesTestCase):
         self.assertEqual(get_version(), 'test')
 
 
+@override_settings(AXES_ENABLED=False)
+class AxesDisabledTestCase(AxesTestCase):
+    def test_initialize(self):
+        AppConfig.logging_initialized = False
+        AppConfig.initialize()
+        self.assertFalse(AppConfig.logging_initialized)
+
+    def test_toggleable(self):
+        def is_true():
+            return True
+
+        self.assertTrue(is_true())
+        self.assertIsNone(toggleable(is_true)())
+
+
 class CacheTestCase(AxesTestCase):
     @override_settings(AXES_COOLOFF_TIME=3)  # hours
     def test_get_cache_timeout_integer(self):
@@ -367,7 +383,7 @@ class UsernameTestCase(AxesTestCase):
     def test_default_get_client_username(self):
         expected = 'test-username'
 
-        request = AxesHttpRequest()
+        request = HttpRequest()
         request.POST['username'] = expected
 
         actual = get_client_username(request)
@@ -379,7 +395,7 @@ class UsernameTestCase(AxesTestCase):
         expected = 'test-username'
         expected_in_credentials = 'test-credentials-username'
 
-        request = AxesHttpRequest()
+        request = HttpRequest()
         request.POST['username'] = expected
         credentials = {
             'username': expected_in_credentials
@@ -399,7 +415,7 @@ class UsernameTestCase(AxesTestCase):
         expected = 'prefixed-' + provided
         provided_in_credentials = 'test-credentials-username'
 
-        request = AxesHttpRequest()
+        request = HttpRequest()
         request.POST['username'] = provided
         credentials = {'username': provided_in_credentials}
 
@@ -417,7 +433,7 @@ class UsernameTestCase(AxesTestCase):
         provided_in_credentials = 'test-credentials-username'
         expected_in_credentials = 'prefixed-' + provided_in_credentials
 
-        request = AxesHttpRequest()
+        request = HttpRequest()
         request.POST['username'] = provided
         credentials = {'username': provided_in_credentials}
 
@@ -427,38 +443,38 @@ class UsernameTestCase(AxesTestCase):
 
     @override_settings(AXES_USERNAME_CALLABLE=lambda request, credentials: 'example')  # pragma: no cover
     def test_get_client_username(self):
-        self.assertEqual(get_client_username(AxesHttpRequest(), {}), 'example')
+        self.assertEqual(get_client_username(HttpRequest(), {}), 'example')
 
     @override_settings(AXES_USERNAME_CALLABLE=lambda request: None)  # pragma: no cover
     def test_get_client_username_invalid_callable_too_few_arguments(self):
         with self.assertRaises(TypeError):
-            get_client_username(AxesHttpRequest(), {})
+            get_client_username(HttpRequest(), {})
 
     @override_settings(AXES_USERNAME_CALLABLE=lambda request, credentials, extra: None)  # pragma: no cover
     def test_get_client_username_invalid_callable_too_many_arguments(self):
         with self.assertRaises(TypeError):
-            get_client_username(AxesHttpRequest(), {})
+            get_client_username(HttpRequest(), {})
 
     @override_settings(AXES_USERNAME_CALLABLE=True)
     def test_get_client_username_not_callable(self):
         with self.assertRaises(TypeError):
-            get_client_username(AxesHttpRequest(), {})
+            get_client_username(HttpRequest(), {})
 
     @override_settings(AXES_USERNAME_CALLABLE='axes.tests.test_utils.get_username')
     def test_get_client_username_str(self):
         self.assertEqual(
-            get_client_username(AxesHttpRequest(), {}),
+            get_client_username(HttpRequest(), {}),
             'username',
         )
 
 
-def get_username(request: AxesHttpRequest, credentials: dict) -> str:
+def get_username(request, credentials: dict) -> str:
     return 'username'
 
 
 class IPWhitelistTestCase(AxesTestCase):
     def setUp(self):
-        self.request = AxesHttpRequest()
+        self.request = HttpRequest()
         self.request.method = 'POST'
         self.request.META['REMOTE_ADDR'] = '127.0.0.1'
         self.request.axes_ip_address = '127.0.0.1'
@@ -517,7 +533,7 @@ class IPWhitelistTestCase(AxesTestCase):
 
 class MethodWhitelistTestCase(AxesTestCase):
     def setUp(self):
-        self.request = AxesHttpRequest()
+        self.request = HttpRequest()
         self.request.method = 'GET'
 
     @override_settings(AXES_NEVER_LOCKOUT_GET=True)
@@ -531,7 +547,7 @@ class MethodWhitelistTestCase(AxesTestCase):
 
 class LockoutResponseTestCase(AxesTestCase):
     def setUp(self):
-        self.request = AxesHttpRequest()
+        self.request = HttpRequest()
 
     @override_settings(AXES_COOLOFF_TIME=42)
     def test_get_lockout_response_cool_off(self):
